scrunch
=======

Pythonic scripting library for cleaning data in Crunch.

|Build Status|

For more information see the
`Overview <https://github.com/Crunch-io/scrunch/wiki/Overview>`__ wiki
page.

.. |Build Status| image:: https://travis-ci.org/Crunch-io/scrunch.svg?branch=master
   :target: https://travis-ci.org/Crunch-io/scrunch
